@@ -36,6 +36,13 @@ class CodeCommitBackend(BaseBackend):
     def __init__(self):
         self.repositories = {}
 
+    @staticmethod
+    def default_vpc_endpoint_service(service_region, zones):
+        """Default VPC endpoint service."""
+        return BaseBackend.default_vpc_endpoint_service_factory(
+            service_region, zones, "codecommit"
+        )
+
     def create_repository(self, region, repository_name, repository_description):
         repository = self.repositories.get(repository_name)
         if repository:
