@@ -71,6 +71,13 @@ class CodePipelineBackend(BaseBackend):
     def __init__(self):
         self.pipelines = {}
 
+    @staticmethod
+    def default_vpc_endpoint_service(service_region, zones):
+        """Default VPC endpoint service."""
+        return BaseBackend.default_vpc_endpoint_service_factory(
+            service_region, zones, "codepipeline", policy_supported=False
+        )
+
     @property
     def iam_backend(self):
         return iam_backends["global"]
