@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 from moto.core.responses import BaseResponse
 from .models import cognitoidentity_backends
 from .utils import get_random_identity_id
@@ -55,7 +53,9 @@ class CognitoIdentityResponse(BaseResponse):
         )
 
     def get_id(self):
-        return cognitoidentity_backends[self.region].get_id()
+        return cognitoidentity_backends[self.region].get_id(
+            identity_pool_id=self._get_param("IdentityPoolId"),
+        )
 
     def describe_identity_pool(self):
         return cognitoidentity_backends[self.region].describe_identity_pool(
@@ -78,3 +78,8 @@ class CognitoIdentityResponse(BaseResponse):
         return cognitoidentity_backends[self.region].get_open_id_token(
             self._get_param("IdentityId") or get_random_identity_id(self.region)
         )
+
+    def list_identities(self):
+        return cognitoidentity_backends[self.region].list_identities(
+            self._get_param("IdentityPoolId") or get_random_identity_id(self.region)
+        )
