@@ -791,7 +791,7 @@ class ConfigRule(ConfigEmptyDictable):
         # Verify input parameter names are actual parameters for the rule ID.
         if param_names:
             allowed_names = {x["Name"] for x in rule_info["Parameters"]}
-            if allowed_names.difference(set(param_names)):
+            if not set(param_names).issubset(allowed_names):
                 raise InvalidParameterValueException(
                     "Unknown parameters provided in the inputParameters: "
                     + self.input_parameters.replace('"', '\\"')
@@ -854,6 +854,13 @@ class ConfigBackend(BaseBackend):
         self.config_rules = {}
         self.config_schema = None
 
+    @staticmethod
+    def default_vpc_endpoint_service(service_region, zones):
+        """List of dicts representing default VPC endpoints for this service."""
+        return BaseBackend.default_vpc_endpoint_service_factory(
+            service_region, zones, "config"
+        )
+
     def _validate_resource_types(self, resource_list):
         if not self.config_schema:
             self.config_schema = AWSServiceSpec(
