@@ -112,6 +112,13 @@ class DataSyncBackend(BaseBackend):
         self.__dict__ = {}
         self.__init__(region_name)
 
+    @staticmethod
+    def default_vpc_endpoint_service(service_region, zones):
+        """Default VPC endpoint service."""
+        return BaseBackend.default_vpc_endpoint_service_factory(
+            service_region, zones, "datasync"
+        )
+
     def create_location(self, location_uri, typ=None, metadata=None):
         """
         # AWS DataSync allows for duplicate LocationUris
