@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 from collections import defaultdict
 import datetime
 import json
@@ -152,7 +151,7 @@ class Table(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         properties = cloudformation_json["Properties"]
         key_attr = [
@@ -301,6 +300,10 @@ class Table(CloudFormationModel):
                 item.attrs[attr].add(DynamoType(update["Value"]))
         return item
 
+    @classmethod
+    def has_cfn_attr(cls, attribute):
+        return attribute in ["StreamArn"]
+
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
 
