@@ -206,6 +206,13 @@ class UpdateHashRangeKeyException(MockValidationException):
         super(UpdateHashRangeKeyException, self).__init__(self.msg.format(key_name))
 
 
+class InvalidAttributeTypeError(MockValidationException):
+    msg = "One or more parameter values were invalid: Type mismatch for key {} expected: {} actual: {}"
+
+    def __init__(self, name, expected_type, actual_type):
+        super().__init__(self.msg.format(name, expected_type, actual_type))
+
+
 class TooManyAddClauses(InvalidUpdateExpression):
     msg = 'The "ADD" section can only be used once in an update expression;'
 
