@@ -4,8 +4,6 @@ See AWS docs for details:
 https://docs.aws.amazon.com/efs/latest/ug/whatisefs.html
 """
 
-from __future__ import unicode_literals
-
 import json
 import time
 from copy import deepcopy
@@ -175,7 +173,7 @@ class FileSystem(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html
         props = deepcopy(cloudformation_json["Properties"])
@@ -287,7 +285,7 @@ class MountTarget(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         # https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-mounttarget.html
         props = deepcopy(cloudformation_json["Properties"])
