@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import datetime
 import re
 from jinja2 import Template
@@ -160,7 +158,7 @@ class FakeTargetGroup(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         properties = cloudformation_json["Properties"]
 
@@ -255,7 +253,7 @@ class FakeListener(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         properties = cloudformation_json["Properties"]
 
@@ -319,7 +317,7 @@ class FakeListenerRule(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         properties = cloudformation_json["Properties"]
         elbv2_backend = elbv2_backends[region_name]
@@ -427,6 +425,8 @@ class FakeLoadBalancer(CloudFormationModel):
         "access_logs.s3.prefix",
         "deletion_protection.enabled",
         "idle_timeout.timeout_seconds",
+        "routing.http2.enabled",
+        "routing.http.drop_invalid_header_fields.enabled",
     }
 
     def __init__(
@@ -498,7 +498,7 @@ class FakeLoadBalancer(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         properties = cloudformation_json["Properties"]
 
@@ -513,6 +513,16 @@ class FakeLoadBalancer(CloudFormationModel):
         )
         return load_balancer
 
+    @classmethod
+    def has_cfn_attr(cls, attribute):
+        return attribute in [
+            "DNSName",
+            "LoadBalancerName",
+            "CanonicalHostedZoneID",
+            "LoadBalancerFullName",
+            "SecurityGroups",
+        ]
+
     def get_cfn_attribute(self, attribute_name):
         """
         Implemented attributes:
