@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import json
 import os
 from collections import defaultdict
@@ -12,7 +10,13 @@ from moto.core.utils import unix_time
 from moto.utilities.tagging_service import TaggingService
 from moto.core.exceptions import JsonRESTError
 
-from .utils import decrypt, encrypt, generate_key_id, generate_master_key
+from .utils import (
+    RESERVED_ALIASES,
+    decrypt,
+    encrypt,
+    generate_key_id,
+    generate_master_key,
+)
 
 
 class Key(CloudFormationModel):
@@ -127,7 +131,7 @@ class Key(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        self, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         kms_backend = kms_backends[region_name]
         properties = cloudformation_json["Properties"]
@@ -145,6 +149,10 @@ class Key(CloudFormationModel):
 
         return key
 
+    @classmethod
+    def has_cfn_attr(cls, attribute):
+        return attribute in ["Arn"]
+
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
 
@@ -154,11 +162,18 @@ class Key(CloudFormationModel):
 
 
 class KmsBackend(BaseBackend):
-    def __init__(self):
+    def __init__(self, region):
+        self.region = region
         self.keys = {}
         self.key_to_aliases = defaultdict(set)
         self.tagger = TaggingService(key_name="TagKey", value_name="TagValue")
 
+    def reset(self):
+        region = self.region
+        self._reset_model_refs()
+        self.__dict__ = {}
+        self.__init__(region)
+
     @staticmethod
     def default_vpc_endpoint_service(service_region, zones):
         """Default VPC endpoint service."""
@@ -166,6 +181,20 @@ class KmsBackend(BaseBackend):
             service_region, zones, "kms"
         )
 
+    def _generate_default_keys(self, alias_name):
+        """Creates default kms keys """
+        if alias_name in RESERVED_ALIASES:
+            key = self.create_key(
+                None,
+                "ENCRYPT_DECRYPT",
+                "SYMMETRIC_DEFAULT",
+                "Default key",
+                None,
+                self.region,
+            )
+            self.add_alias(key.id, alias_name)
+            return key.id
+
     def create_key(
         self, policy, key_usage, customer_master_key_spec, description, tags, region
     ):
@@ -192,7 +221,7 @@ class KmsBackend(BaseBackend):
         # describe key not just KeyId
         key_id = self.get_key_id(key_id)
         if r"alias/" in str(key_id).lower():
-            key_id = self.get_key_id_from_alias(key_id.split("alias/")[1])
+            key_id = self.get_key_id_from_alias(key_id)
         return self.keys[self.get_key_id(key_id)]
 
     def list_keys(self):
@@ -252,6 +281,9 @@ class KmsBackend(BaseBackend):
         for key_id, aliases in dict(self.key_to_aliases).items():
             if alias_name in ",".join(aliases):
                 return key_id
+        if alias_name in RESERVED_ALIASES:
+            key_id = self._generate_default_keys(alias_name)
+            return key_id
         return None
 
     def enable_key_rotation(self, key_id):
@@ -385,8 +417,8 @@ class KmsBackend(BaseBackend):
 
 kms_backends = {}
 for region in Session().get_available_regions("kms"):
-    kms_backends[region] = KmsBackend()
+    kms_backends[region] = KmsBackend(region)
 for region in Session().get_available_regions("kms", partition_name="aws-us-gov"):
-    kms_backends[region] = KmsBackend()
+    kms_backends[region] = KmsBackend(region)
 for region in Session().get_available_regions("kms", partition_name="aws-cn"):
-    kms_backends[region] = KmsBackend()
+    kms_backends[region] = KmsBackend(region)
