@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import json
 from moto.sagemaker.exceptions import AWSValidationException
 
@@ -134,6 +132,12 @@ class SageMakerResponse(BaseResponse):
                 tags = self.sagemaker_backend.get_endpoint_tags(arn)
             elif ":training-job/" in arn:
                 tags = self.sagemaker_backend.get_training_job_tags(arn)
+            elif ":experiment/" in arn:
+                tags = self.sagemaker_backend.get_experiment_tags(arn)
+            elif ":experiment-trial/" in arn:
+                tags = self.sagemaker_backend.get_trial_tags(arn)
+            elif ":experiment-trial-component/" in arn:
+                tags = self.sagemaker_backend.get_trial_component_tags(arn)
             else:
                 tags = []
         except AWSError:
@@ -141,6 +145,30 @@ class SageMakerResponse(BaseResponse):
         response = {"Tags": tags}
         return 200, {}, json.dumps(response)
 
+    @amzn_request_id
+    def add_tags(self):
+        arn = self._get_param("ResourceArn")
+        tags = self._get_param("Tags")
+        if ":experiment/" in arn:
+            self.sagemaker_backend.add_tags_to_experiment(arn, tags)
+        elif ":experiment-trial/" in arn:
+            self.sagemaker_backend.add_tags_to_trial(arn, tags)
+        elif ":experiment-trial-component/" in arn:
+            self.sagemaker_backend.add_tags_to_trial_component(arn, tags)
+        return 200, {}, json.dumps({})
+
+    @amzn_request_id
+    def delete_tags(self):
+        arn = self._get_param("ResourceArn")
+        tag_keys = self._get_param("TagKeys")
+        if ":experiment/" in arn:
+            self.sagemaker_backend.delete_tags_from_experiment(arn, tag_keys)
+        elif ":experiment-trial/" in arn:
+            self.sagemaker_backend.delete_tags_from_trial(arn, tag_keys)
+        elif ":experiment-trial-component/" in arn:
+            self.sagemaker_backend.delete_tags_from_trial_component(arn, tag_keys)
+        return 200, {}, json.dumps({})
+
     @amzn_request_id
     def create_endpoint_config(self):
         try:
@@ -197,6 +225,33 @@ class SageMakerResponse(BaseResponse):
         self.sagemaker_backend.delete_endpoint(endpoint_name)
         return 200, {}, json.dumps("{}")
 
+    @amzn_request_id
+    def create_processing_job(self):
+        try:
+            processing_job = self.sagemaker_backend.create_processing_job(
+                app_specification=self._get_param("AppSpecification"),
+                experiment_config=self._get_param("ExperimentConfig"),
+                network_config=self._get_param("NetworkConfig"),
+                processing_inputs=self._get_param("ProcessingInputs"),
+                processing_job_name=self._get_param("ProcessingJobName"),
+                processing_output_config=self._get_param("ProcessingOutputConfig"),
+                processing_resources=self._get_param("ProcessingResources"),
+                role_arn=self._get_param("RoleArn"),
+                stopping_condition=self._get_param("StoppingCondition"),
+            )
+            response = {
+                "ProcessingJobArn": processing_job.processing_job_arn,
+            }
+            return 200, {}, json.dumps(response)
+        except AWSError as err:
+            return err.response()
+
+    @amzn_request_id
+    def describe_processing_job(self):
+        processing_job_name = self._get_param("ProcessingJobName")
+        response = self.sagemaker_backend.describe_processing_job(processing_job_name)
+        return json.dumps(response)
+
     @amzn_request_id
     def create_training_job(self):
         try:
@@ -280,6 +335,180 @@ class SageMakerResponse(BaseResponse):
         )
         return 200, {}, json.dumps("{}")
 
+    @amzn_request_id
+    def search(self):
+        response = self.sagemaker_backend.search(
+            resource=self._get_param("Resource"),
+            search_expression=self._get_param("SearchExpression"),
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def list_experiments(self):
+        response = self.sagemaker_backend.list_experiments()
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def delete_experiment(self):
+        self.sagemaker_backend.delete_experiment(
+            experiment_name=self._get_param("ExperimentName"),
+        )
+        return 200, {}, json.dumps({})
+
+    @amzn_request_id
+    def create_experiment(self, *args, **kwargs):
+        response = self.sagemaker_backend.create_experiment(
+            experiment_name=self._get_param("ExperimentName"),
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def describe_experiment(self, *args, **kwargs):
+        response = self.sagemaker_backend.describe_experiment(
+            experiment_name=self._get_param("ExperimentName"),
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def list_trials(self):
+        response = self.sagemaker_backend.list_trials(
+            experiment_name=self._get_param("ExperimentName"),
+            trial_component_name=self._get_param("TrialComponentName"),
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def create_trial(self, *args, **kwargs):
+        try:
+            response = self.sagemaker_backend.create_trial(
+                trial_name=self._get_param("TrialName"),
+                experiment_name=self._get_param("ExperimentName"),
+            )
+            return 200, {}, json.dumps(response)
+        except AWSError as err:
+            return err.response()
+
+    @amzn_request_id
+    def list_trial_components(self):
+        response = self.sagemaker_backend.list_trial_components(
+            trial_name=self._get_param("TrialName"),
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def create_trial_component(self, *args, **kwargs):
+        try:
+            response = self.sagemaker_backend.create_trial_component(
+                trial_component_name=self._get_param("TrialComponentName"),
+                trial_name=self._get_param("TrialName"),
+            )
+            return 200, {}, json.dumps(response)
+        except AWSError as err:
+            return err.response()
+
+    @amzn_request_id
+    def describe_trial(self, *args, **kwargs):
+        trial_name = self._get_param("TrialName")
+        response = self.sagemaker_backend.describe_trial(trial_name)
+        return json.dumps(response)
+
+    @amzn_request_id
+    def delete_trial(self):
+        trial_name = self._get_param("TrialName")
+        self.sagemaker_backend.delete_trial(trial_name)
+        return 200, {}, json.dumps({})
+
+    @amzn_request_id
+    def delete_trial_component(self):
+        trial_component_name = self._get_param("TrialComponentName")
+        self.sagemaker_backend.delete_trial_component(trial_component_name)
+        return 200, {}, json.dumps({})
+
+    @amzn_request_id
+    def describe_trial_component(self, *args, **kwargs):
+        trial_component_name = self._get_param("TrialComponentName")
+        response = self.sagemaker_backend.describe_trial_component(trial_component_name)
+        return json.dumps(response)
+
+    @amzn_request_id
+    def associate_trial_component(self, *args, **kwargs):
+        response = self.sagemaker_backend.associate_trial_component(self.request_params)
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def disassociate_trial_component(self, *args, **kwargs):
+        response = self.sagemaker_backend.disassociate_trial_component(
+            self.request_params
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def list_associations(self, *args, **kwargs):
+        response = self.sagemaker_backend.list_associations(self.request_params)
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def list_processing_jobs(self):
+        max_results_range = range(1, 101)
+        allowed_sort_by = ["Name", "CreationTime", "Status"]
+        allowed_sort_order = ["Ascending", "Descending"]
+        allowed_status_equals = [
+            "Completed",
+            "Stopped",
+            "InProgress",
+            "Stopping",
+            "Failed",
+        ]
+
+        try:
+            max_results = self._get_int_param("MaxResults")
+            sort_by = self._get_param("SortBy", "CreationTime")
+            sort_order = self._get_param("SortOrder", "Ascending")
+            status_equals = self._get_param("StatusEquals")
+            next_token = self._get_param("NextToken")
+            errors = []
+            if max_results and max_results not in max_results_range:
+                errors.append(
+                    "Value '{0}' at 'maxResults' failed to satisfy constraint: Member must have value less than or equal to {1}".format(
+                        max_results, max_results_range[-1]
+                    )
+                )
+
+            if sort_by not in allowed_sort_by:
+                errors.append(format_enum_error(sort_by, "sortBy", allowed_sort_by))
+            if sort_order not in allowed_sort_order:
+                errors.append(
+                    format_enum_error(sort_order, "sortOrder", allowed_sort_order)
+                )
+
+            if status_equals and status_equals not in allowed_status_equals:
+                errors.append(
+                    format_enum_error(
+                        status_equals, "statusEquals", allowed_status_equals
+                    )
+                )
+
+            if errors != []:
+                raise AWSValidationException(
+                    f"{len(errors)} validation errors detected: {';'.join(errors)}"
+                )
+
+            response = self.sagemaker_backend.list_processing_jobs(
+                next_token=next_token,
+                max_results=max_results,
+                creation_time_after=self._get_param("CreationTimeAfter"),
+                creation_time_before=self._get_param("CreationTimeBefore"),
+                last_modified_time_after=self._get_param("LastModifiedTimeAfter"),
+                last_modified_time_before=self._get_param("LastModifiedTimeBefore"),
+                name_contains=self._get_param("NameContains"),
+                status_equals=status_equals,
+                sort_by=sort_by,
+                sort_order=sort_order,
+            )
+            return 200, {}, json.dumps(response)
+        except AWSError as err:
+            return err.response()
+
     @amzn_request_id
     def list_training_jobs(self):
         max_results_range = range(1, 101)
