@@ -1,11 +1,10 @@
-from __future__ import unicode_literals
-
 import argparse
 import io
 import json
 import os
 import signal
 import sys
+from functools import partial
 from threading import Lock
 
 from flask import Flask
@@ -20,7 +19,7 @@ import moto.backends as backends
 import moto.backend_index as backend_index
 from moto.core.utils import convert_flask_to_httpretty_response
 
-HTTP_METHODS = ["GET", "POST", "PUT", "DELETE", "HEAD", "PATCH"]
+HTTP_METHODS = ["GET", "POST", "PUT", "DELETE", "HEAD", "PATCH", "OPTIONS"]
 
 
 DEFAULT_SERVICE_REGION = ("s3", "us-east-1")
@@ -58,6 +57,7 @@ class DomainDispatcherApplication(object):
         self.backend_url_patterns = backend_index.backend_url_patterns
 
     def get_backend_for_host(self, host):
+
         if host == "moto_api":
             return host
 
@@ -107,8 +107,10 @@ class DomainDispatcherApplication(object):
                 # See if we can match the Action to a known service
                 service, region = UNSIGNED_ACTIONS.get(action)
             else:
-                # S3 is the last resort when the target is also unknown
-                service, region = DEFAULT_SERVICE_REGION
+                service, region = self.get_service_from_path(environ)
+                if not service:
+                    # S3 is the last resort when the target is also unknown
+                    service, region = DEFAULT_SERVICE_REGION
 
         if service == "mediastore" and not target:
             # All MediaStore API calls have a target header
@@ -130,6 +132,10 @@ class DomainDispatcherApplication(object):
             host = "api.{service}.{region}.amazonaws.com".format(
                 service=service, region=region
             )
+        elif service == "timestream":
+            host = "ingest.{service}.{region}.amazonaws.com".format(
+                service=service, region=region
+            )
         else:
             host = "{service}.{region}.amazonaws.com".format(
                 service=service, region=region
@@ -184,6 +190,16 @@ class DomainDispatcherApplication(object):
                 environ["wsgi.input"] = io.StringIO(body)
         return None
 
+    def get_service_from_path(self, environ):
+        # Moto sometimes needs to send a HTTP request to itself
+        # In which case it will send a request to 'http://localhost/service_region/whatever'
+        try:
+            path_info = environ.get("PATH_INFO", "/")
+            service, region = path_info[1 : path_info.index("/", 1)].split("_")
+            return service, region
+        except (KeyError, ValueError):
+            return None, None
+
     def __call__(self, environ, start_response):
         backend_app = self.get_application(environ)
         return backend_app(environ, start_response)
@@ -249,20 +265,25 @@ def create_backend_app(service):
             endpoint = original_endpoint + str(index)
             index += 1
 
-        backend_app.add_url_rule(
-            url_path,
-            endpoint=endpoint,
-            methods=HTTP_METHODS,
-            view_func=view_func,
-            strict_slashes=False,
-        )
+        # Some services do not provide a URL path
+        # I.e., boto3 sends a request to 'https://ingest.timestream.amazonaws.com'
+        # Which means we have a empty url_path to catch this request - but Flask can't handle that
+        if url_path:
+            backend_app.add_url_rule(
+                url_path,
+                endpoint=endpoint,
+                methods=HTTP_METHODS,
+                view_func=view_func,
+                strict_slashes=False,
+            )
 
     backend_app.test_client_class = AWSTestHelper
     return backend_app
 
 
-def signal_handler(signum, frame):
-    print("Received signal %d" % signum)
+def signal_handler(reset_server_port, signum, frame):
+    if reset_server_port:
+        del os.environ["MOTO_SERVER_PORT"]
     sys.exit(0)
 
 
@@ -305,9 +326,14 @@ def main(argv=sys.argv[1:]):
 
     args = parser.parse_args(argv)
 
+    reset_server_port = False
+    if "MOTO_SERVER_PORT" not in os.environ:
+        reset_server_port = True
+        os.environ["MOTO_SERVER_PORT"] = f"{args.port}"
+
     try:
-        signal.signal(signal.SIGINT, signal_handler)
-        signal.signal(signal.SIGTERM, signal_handler)
+        signal.signal(signal.SIGINT, partial(signal_handler, reset_server_port))
+        signal.signal(signal.SIGTERM, partial(signal_handler, reset_server_port))
     except Exception:
         pass  # ignore "ValueError: signal only works in main thread"
 
