@@ -1,5 +1,3 @@
-from __future__ import unicode_literals
-
 import datetime
 import uuid
 import json
@@ -55,6 +53,8 @@ class Topic(CloudFormationModel):
             sns_backend.region_name, self.account_id, name
         )
         self._tags = {}
+        self.fifo_topic = "false"
+        self.content_based_deduplication = "false"
 
     def publish(self, message, subject=None, message_attributes=None):
         message_id = str(uuid.uuid4())
@@ -68,6 +68,10 @@ class Topic(CloudFormationModel):
             )
         return message_id
 
+    @classmethod
+    def has_cfn_attr(cls, attribute):
+        return attribute in ["TopicName"]
+
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
 
@@ -98,7 +102,7 @@ class Topic(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         sns_backend = sns_backends[region_name]
         properties = cloudformation_json["Properties"]
@@ -308,7 +312,7 @@ class Subscription(BaseModel):
             "Type": "Notification",
             "MessageId": message_id,
             "TopicArn": self.topic.arn,
-            "Subject": subject or "my subject",
+            "Subject": subject,
             "Message": message,
             "Timestamp": iso_8601_datetime_with_milliseconds(
                 datetime.datetime.utcnow()
